==> blender_2.66a.orig.tar.bz2: blender-2.66a/source/blender/nodes/composite/nodes/node_composite_movieclip.c <==
/*
 * ***** BEGIN GPL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The Original Code is Copyright (C) 2011 Blender Foundation.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): Blender Foundation,
 *                 Sergey Sharybin
 *
 * ***** END GPL LICENSE BLOCK *****
 */

/** \file blender/nodes/composite/nodes/node_composite_movieclip.c
 *  \ingroup cmpnodes
 */


#include "node_composite_util.h"

static bNodeSocketTemplate cmp_node_movieclip_out[] = {
	{	SOCK_RGBA,		0,	N_("Image")},
	{	SOCK_FLOAT,		1,	N_("Offset X")},
	{	SOCK_FLOAT,		1,	N_("Offset Y")},
	{	SOCK_FLOAT,		1,	N_("Scale")},
	{	SOCK_FLOAT,		1,	N_("Angle")},
	{	-1, 0, ""	}
};

static void init(bNodeTree *UNUSED(ntree), bNode *node, bNodeTemplate *UNUSED(ntemp))
{
	MovieClipUser *user = MEM_callocN(sizeof(MovieClipUser), "node movie clip user");

	node->storage = user;
	user->framenr = 1;
}

void register_node_type_cmp_movieclip(bNodeTreeType *ttype)
{
	static bNodeType ntype;

	node_type_base(ttype, &ntype, CMP_NODE_MOVIECLIP, "Movie Clip", NODE_CLASS_INPUT, NODE_PREVIEW|NODE_OPTIONS);
	node_type_socket_templates(&ntype, NULL, cmp_node_movieclip_out);
	node_type_size(&ntype, 120, 80, 300);
	node_type_init(&ntype, init);
	node_type_storage(&ntype, "MovieClipUser", node_free_standard_storage, node_copy_standard_storage);

	nodeRegisterType(ttype, &ntype);
}

==> blender_2.69.orig.tar.bz2: blender-2.69/source/blender/nodes/composite/nodes/node_composite_movieclip.c <==
/*
 * ***** BEGIN GPL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The Original Code is Copyright (C) 2011 Blender Foundation.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): Blender Foundation,
 *                 Sergey Sharybin
 *
 * ***** END GPL LICENSE BLOCK *****
 */

/** \file blender/nodes/composite/nodes/node_composite_movieclip.c
 *  \ingroup cmpnodes
 */


#include "node_composite_util.h"

#include "BKE_context.h"

#include "RNA_access.h"

static bNodeSocketTemplate cmp_node_movieclip_out[] = {
	{	SOCK_RGBA,		0,	N_("Image")},
	{	SOCK_FLOAT,		0,	N_("Alpha")},
	{	SOCK_FLOAT,		1,	N_("Offset X")},
	{	SOCK_FLOAT,		1,	N_("Offset Y")},
	{	SOCK_FLOAT,		1,	N_("Scale")},
	{	SOCK_FLOAT,		1,	N_("Angle")},
	{	-1, 0, ""	}
};

static void init(const bContext *C, PointerRNA *ptr)
{
	bNode *node = ptr->data;
	Scene *scene = CTX_data_scene(C);
	MovieClipUser *user = MEM_callocN(sizeof(MovieClipUser), "node movie clip user");

	node->id = (ID *)scene->clip;
	node->storage = user;
	user->framenr = 1;
}

void register_node_type_cmp_movieclip(void)
{
	static bNodeType ntype;

	cmp_node_type_base(&ntype, CMP_NODE_MOVIECLIP, "Movie Clip", NODE_CLASS_INPUT, NODE_PREVIEW);
	node_type_socket_templates(&ntype, NULL, cmp_node_movieclip_out);
	ntype.initfunc_api = init;
	node_type_storage(&ntype, "MovieClipUser", node_free_standard_storage, node_copy_standard_storage);

	nodeRegisterType(&ntype);
}
